package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````S!\```````!```````````"D````
M````!0```$``.``*`$``&@`9``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````A`````````"$``````````0`````````#``!P
M!````*ZB`````````````````````````````%,````````````````````!
M``````````$````%````````````````````````````````````')4`````
M```<E0`````````0`````````0````8```#8G0```````-BM````````V*T`
M``````"X!````````.`$`````````!`````````"````!@```/"=````````
M\*T```````#PK0```````!`"````````$`(````````(``````````0````$
M````E`(```````"4`@```````)0"````````1`````````!$``````````0`
M````````4.5T9`0```!HC0```````&B-````````:(T````````$`0``````
M``0!````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````V)T```````#8
MK0```````-BM````````*`(````````H`@````````$`````````+VQI8B]L
M9"UL:6YU>"UR:7-C=C8T+6QP-C1D+G-O+C$`````!````!0````#````1TY5
M`*I!YU-%"`L!Q"O7T!5CC8$9-V;0!````!`````!````1TY5```````$````
M#P`````````1````1P````0````(````()`0`05`!,0H`@$$@(8$A(*)``()
M(`0(B(`00;H``H@`````1P```$H```!-````3@```%8```!7````60```%L`
M``!<````70```%\```!A````8@```&0``````````````&[%WQ_.WD<M:W^:
M?"[%F[;49-1\(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_++KCDGSZH6Q@
MF4_#FVL)0]9FK\QF&7X*AT)%U>R)!W#3<U"?V#-BV^T^S])L%8PES`PZEPO_
M8?)A?ZF<F^"G`@IK&IY0H^#[20``````````````````````````````````
M`````````P`,`$`>``````````````````#;`@``$0``````````````````
M``````#5````$@````````````````````````#-`0``$@``````````````
M``````````"W`@``$@````````````````````````"'````$@``````````
M``````````````!.`0``$@````````````````````````"*`@``$@``````
M``````````````````#4`0``$@````````````````````````!E`0``$@``
M``````````````````````"5`0``$@````````````````````````#K````
M$@````````````````````````"F`@``$@````````````````````````#!
M`@``$0````````````````````````"1`@``$@``````````````````````
M``"(`0``$@`````````````````````````<`0``$@``````````````````
M```````,`0``$@````````````````````````#^````$@``````````````
M``````````#S`0``$@````````````````````````#;`0``$@``````````
M``````````````#F`0``$@````````````````````````"^`0``$@``````
M``````````````````#)`@``$@`````````````````````````!````(```
M```````````````````````)`@``$@````````````````````````!L`0``
M$@`````````````````````````=````(``````````````````````````W
M`@``$@````````````````````````"F`0``$@``````````````````````
M```W````$@````````````````````````"8`@``$@``````````````````
M``````"_`@``$0````````````````````````!4````%@``````````````
M```````````"`@``$@`````````````````````````^`0``$@``````````
M``````````````"?`@``$@````````````````````````!G````$@``````
M``````````````````!T`@``$@````````````````````````#$````$@``
M``````````````````````!X````$@````````````````````````"-`0``
M$@````````````````````````"H````$@````````````````````````#:
M````$@````````````````````````#%`0``$@``````````````````````
M``!M`@``$@````````````````````````#M`0``$@``````````````````
M```````P`0``$@````````````````````````"?`0``$@``````````````
M``````````!7`@``$@````````````````````````!0`@``$0``````````
M``````````````#?````$@````````````````````````"V`0``$@``````
M```````````````````V`@``$@````````````````````````!>`@``(@``
M``````````````````````"3````$@`````````````````````````2`@``
M$@````````````````````````#A`0``$@````````````````````````![
M`@``$@````````````````````````!9`0``$@``````````````````````
M```H`@``$@````````````````````````"C`P``$@``````````````````
M``````"W````$0`````````````````````````:`@``$@``````````````
M```````````E`0``$@````````````````````````!%````$@``````````
M```````````````^`@``$@````````````````````````""`@``$@``````
M``````````````````!W`0``$@````````````````````````"O`0``$@``
M``````````````````````"L`P``$@`,`.HU````````J``````````^!```
M$@`,`%XO````````W`0```````!+`@``$@`,`$`>````````B@$````````C
M`P``$@`,`&0F`````````@````````!!`P``$@`,`#HT````````L`$`````
M``!D!```$@`,`&8F````````U@$````````D!```$``6`)"R````````````
M```````T`P``$@`,`#PH````````(@````````!7`P``$@`,`+@L````````
M3@````````#$`P``$0`-`/!+````````!``````````!!```$@`,`%!)````
M````W``````````<!```$@`,`'XE````````*``````````Y!```$``6`+BR
M``````````````````!2!```$@`,`(8N````````V`````````![!```$@`,
M``8M````````1`````````#3`P``$``4``"P``````````````````![`P``
M$@`,`%XH`````````@$```````#O`P``$`#Q_P"X``````````````````!+
M!```$``5`)"R``````````````````!Q!```$0`4`$BP````````"```````
M```,!```$``5`)"R``````````````````#9`P``$@`,`,P?````````(@``
M``````#@`P``$``4``"P```````````````````P!```$@`,`/Q(````````
M5`````````#5`P``(``4``"P``````````````````"X`P``$``6`+BR````
M``````````````"1`P``$@`,`&XN````````&`````````!E`P``$@`,`*8E
M````````O@````````"'`P``$@`,`"Q*````````L@$```````"#!```$@`,
M`&`I````````6`,`````````7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE
M`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L
M7W-Y<U]I;FET,P!03%]C=7)R96YT7V-O;G1E>'0`4&5R;%]A=&9O<FM?;&]C
M:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N
M=&5X=`!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F
M;&%G<P!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K
M`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?
M;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S
M90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!?7W-T86-K7V-H:U]F
M86EL`&5X:70`;'-E96LV-`!R96%D9&ER-C0`<W1R9'5P`&-L;W-E9&ER`&]P
M96XV-`!S=')R8VAR`'5N;&EN:P!M96UM;W9E`'-T<G1O:P!S=')L96X`<FUD
M:7(`<F5A9`!S=')S='(`;6MD:7(`7U]V9G!R:6YT9E]C:&L`9V5T<&ED`')E
M861L:6YK`')E86QL;V,`7U]S<')I;G1F7V-H:P!?7V9P<FEN=&9?8VAK`&QS
M=&%T-C0`7U]L:6)C7W-T87)T7VUA:6X`<W1D97)R`&UE;6-H<@!?7V-X85]F
M:6YA;&EZ90!S=')C:'(`;65M8VUP`&UE;7-E=`!O<&5N9&ER`&=E='5I9`!A
M8V-E<W,`;65M8W!Y`'-T<F-M<`!?7V5R<FYO7VQO8V%T:6]N`'-T<FYC;7``
M7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`%]?<W1A8VM?8VAK7V=U87)D
M`&QI8G!E<FPN<V\N-2XS-@!L:6)C+G-O+C8`;&0M;&EN=7@M<FES8W8V-"UL
M<#8T9"YS;RXQ`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%A37TEN
M=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT7V5X
M96-?<')O8P!P87)?9&ER;F%M90!S:&%?9FEN86P`9V5T7W5S97)N86UE7V9R
M;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7U]"4U-?14Y$7U\`7TE/7W-T9&EN
M7W5S960`7U]D871A7W-T87)T`%]?1$%405]"14=)3E]?`%]?9VQO8F%L7W!O
M:6YT97(D`'-H85]U<&1A=&4`7U]31$%405]"14=)3E]?`'AS7VEN:70`7U]B
M<W-?<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A
M<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I
M90!P87)?:6YI=%]E;G8`1TQ)0D-?,BXS-`!'3$E"0U\R+C,S`$=,24)#7S(N
M,C<````````"``$``P`#``$``0`#``,``P`#``$``P`#``,``P`!``$``0`#
M``,``P`#``,``0`#``$``0`$``,``0`#``,``0`#``$``P`!``,``0`!``,`
M`0`#``,``P`#``$``P`#``,``0`#``0``P`!``,``P`#``$``P`#``$``P`!
M``$`!0`#``,``P`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0```````0`#`/T"```0````0```
M`+21E@8```4`D`0``!````"SD98&```$`)L$```0````AY&6!@```P"F!```
M``````$``0`'`P``$`````````"'D98&```"`*8$````````V*T````````#
M`````````.X?````````X*T````````#`````````((@````````Z*T`````
M```#`````````$@@`````````+`````````#``````````"P````````&+``
M```````#`````````%!-````````(+`````````#`````````+A/````````
M*+`````````#`````````,!/````````,+`````````#`````````,A/````
M````.+`````````#`````````-!/````````2+`````````#`````````-A/
M````````B+(````````#`````````$`>````````,+(````````"`````@``
M````````````.+(````````"````#```````````````0+(````````"````
M#@``````````````2+(````````"````&0``````````````4+(````````"
M````'```````````````6+(````````+````(@``````````````8+(`````
M```"````)```````````````:+(````````"````)@``````````````<+(`
M```````"````,P``````````````>+(````````"````-P``````````````
M@+(````````"````/P``````````````8+`````````%`````P``````````
M````:+`````````%````!```````````````<+`````````%````!0``````
M````````>+`````````%````!@``````````````@+`````````%````!P``
M````````````B+`````````%````"```````````````D+`````````%````
M"0``````````````F+`````````%````"@``````````````H+`````````%
M````"P``````````````J+`````````%````#0``````````````L+``````
M```%````#P``````````````N+`````````%````$```````````````P+``
M```````%````$0``````````````R+`````````%````$@``````````````
MT+`````````%````$P``````````````V+`````````%````%```````````
M````X+`````````%````%0``````````````Z+`````````%````%@``````
M````````\+`````````%````%P``````````````^+`````````%````&```
M`````````````+$````````%````&@``````````````"+$````````%````
M&P``````````````$+$````````%````'0``````````````&+$````````%
M````'@``````````````(+$````````%````'P``````````````*+$`````
M```%````(```````````````,+$````````%````(P``````````````.+$`
M```````%````)0``````````````0+$````````%````)P``````````````
M2+$````````%````*```````````````4+$````````%````*0``````````
M````6+$````````%````*@``````````````8+$````````%````*P``````
M````````:+$````````%````+```````````````<+$````````%````+0``
M````````````>+$````````%````+@``````````````@+$````````%````
M+P``````````````B+$````````%````,```````````````D+$````````%
M````,0``````````````F+$````````%````,@``````````````H+$`````
M```%````-```````````````J+$````````%````-0``````````````L+$`
M```````%````-@``````````````N+$````````%````.```````````````
MP+$````````%````.0``````````````R+$````````%````.@``````````
M````T+$````````%````.P``````````````V+$````````%````/```````
M````````X+$````````%````/0``````````````Z+$````````%````/@``
M````````````\+$````````%````0```````````````^+$````````%````
M00```````````````+(````````%````0@``````````````"+(````````%
M````0P``````````````$+(````````%````1```````````````&+(`````
M```%````10``````````````(+(````````%````1@``````````````````
M``````"7DP``,P/#00.^`UP3`T/]DX(#7!-3$P"#LH(`9P`.`!>>```#/@Y;
M9P,.`!,````7G@```SZ.6F<##@`3````%YX```,^#EIG`PX`$P```!>>```#
M/HY99P,.`!,````7G@```SX.66<##@`3````%YX```,^CEAG`PX`$P```!>>
M```#/@Y89P,.`!,````7G@```SZ.5V<##@`3````%YX```,^#E=G`PX`$P``
M`!>>```#/HY69P,.`!,````7G@```SX.5F<##@`3````%YX```,^CE5G`PX`
M$P```!>>```#/@Y59P,.`!,````7G@```SZ.5&<##@`3````%YX```,^#E1G
M`PX`$P```!>>```#/HY39P,.`!,````7G@```SX.4V<##@`3````%YX```,^
MCE)G`PX`$P```!>>```#/@Y29P,.`!,````7G@```SZ.46<##@`3````%YX`
M``,^#E%G`PX`$P```!>>```#/HY09P,.`!,````7G@```SX.4&<##@`3````
M%YX```,^CD]G`PX`$P```!>>```#/@Y/9P,.`!,````7G@```SZ.3F<##@`3
M````%YX```,^#DYG`PX`$P```!>>```#/HY-9P,.`!,````7G@```SX.36<#
M#@`3````%YX```,^CDQG`PX`$P```!>>```#/@Y,9P,.`!,````7G@```SZ.
M2V<##@`3````%YX```,^#DMG`PX`$P```!>>```#/HY*9P,.`!,````7G@``
M`SX.2F<##@`3````%YX```,^CDEG`PX`$P```!>>```#/@Y)9P,.`!,````7
MG@```SZ.2&<##@`3````%YX```,^#DAG`PX`$P```!>>```#/HY'9P,.`!,`
M```7G@```SX.1V<##@`3````%YX```,^CD9G`PX`$P```!>>```#/@Y&9P,.
M`!,````7G@```SZ.16<##@`3````%YX```,^#D5G`PX`$P```!>>```#/HY$
M9P,.`!,````7G@```SX.1&<##@`3````%YX```,^CD-G`PX`$P```!>>```#
M/@Y#9P,.`!,````7G@```SZ.0F<##@`3````%YX```,^#D)G`PX`$P```!>>
M```#/HY!9P,.`!,````7G@```SX.06<##@`3````%YX```,^CD!G`PX`$P``
M`!>>```#/@Y`9P,.`!,````7G@```SZ./V<##@`3````%YX```,^#C]G`PX`
M$P```!UQANRFY*J'HNC*X$[\EY0``(.T)#XNZ#+D#`@P`&@(/LZ<8#[T@4?O
M\)_X%Y8```,VQCRRA1>5```#-24_[R`05I>7``"#M^<_@\<'`/'/EY<``(.W
MASP7E```$P0$0)*7F&-R28-'ITH;!4D`#@63YS<`(P7W2N_PG^["9?)'".28
M80TIJH88X1<W```3!^<-&.47EP```S='%QCI%S<``!,')PT8[05'8UGW#!N(
M-P!"AJ$%$4>(89,7-P"VEP4GB..A!>,9!_^;!P8`C@<(;+:7`4=*AI<%``"3
MA<5@([`'`._PW[P]Q0ALDPE!`N_P']TJB<Z%%S4``!,%A=KO`$`4*<T(;._P
MG[;O\%_.(G><8+F/`4>]Y^9@1F2F9.)Y2H4&:25A@H#O\'_)%Y0``!,$I#((
M["'%[_!_T9>7``"#MZ<MA68SAT<`&&,VEZ,+!Z0QMPAL[_"?O7FW"&@!Q>\0
M@&1%M\Z%%S4``!,%Y<OO`"`-".A9U>6WD4>!OP5%[_#_N>_PO^4``.\`(`*J
MAQ>5```#-64K@F4P`!-Q`?^!1@%'"HCO\)_A`I"7H0``DX$A@8*````7E0``
M$P5E!9>7``"3A^<$8XBG`)>7``"#MZ<CD<."AX*`%Y4``!,%10.7E0``DX7%
M`HF-D]<U0/V1OI6%A9G%EY<``(.W9R&1PX*'@H!!$2+@%Y0``!,$1"2#1P0`
M!N2%XY>7``"#M\<AD<<7E0```S6E^8*7[_"_^(5'(P#T`*)@`F1!`8*`:;\Y
M<0;\(OA9Q5K@EY<``(.W)QL#NP<`8P$+"$KP3NQ2Z(-'!0"JB2Z**HD3!]`#
MI<MCAN<`@T<9``4)_?L["3E!`S0+`#G,)O16Y-J$DPK0`TJ&SH4BA>_P?Y^S
M!R0!">6#QP<`8X!7`X!DH01U\*)T`GGB:4)JHFH":^)P(H5"="%A@H"SA&1!
MC80%"2,@F@!*E/&_`435MP)K`43YOP%)1;<">>)I0FH":\&_<7$B\2;M!O67
ME```@[2$#RP`G&`^Y8%'*H3O\'_`#>'B1[UF$6?UCV.%YP`I9V.:YP")12*%
M[_"_GA,U%0`1H`%%*F><8+F/`4>1YZIP"G3J9$UA@H#O\+_),7%.[0;]EYD`
M`(.Y"0J#MPD`/N6!1QG%(OF#1P4`*H2)[TIT*F>#MPD`N8\!1V.6!PSJ<.II
M*6&"@";U2O'O\)_$JH11R2:%[_#_E4'!@T8U`1,)-0&;AB;]@>:#1AD`_=(#
M1S4!&P<G_3W+(H52Z>_P?Y$JBDJ%[_#_D#L%J@`))>_P7Y'*AR*'ES8``).&
M1IY]5H5%*HGO\/^Z+`!*A>_P?Y[]5V,(]0#B1[UF$6?UCV.`YP1*A>_P_YA*
MA>_PGZ<FA4IJ[_`?CE'Q)H7O\)^<(H7O\#^52G2J=`IYF;<#1QD`&P<G_5'S
M`T<I`"'?M;]*A>_PW_#1MR+Y)O5*\5+I[_!?N1UQHNBFY,K@4OB&[$[\5O1:
M\(/'!0`7F0```SFI^*J$DX<W_).W%P`SA/4`(H6#-PD`/N2!1^_POX0JBDP`
M)H7O\%_;><FJB>_PGX-C=D4+DDH7FP```SOK]8X*`\<$`*:'DP;0`V,(!Q)C
M!M<``\<7`(4'??N%GX,Y"P`3!2H`/I76F>_PWX`CL*D`,<4#-PL`@\<$`!.%
M%`!6EQ1C$P;0`R.`]@"!Z[V@@T<%``4%HP#W`*W#-H>%!N.8Q_Z3!M`#DP<7
M`",`UP`#1P0`A0<%!*./Y_YU^R)G@S<)`+F/`4?=[^9@1F2F9`9IXGE">J)Z
M`GLE88*`@T<$`(4)!02CC_G^\=N#1P0`A0D%!*./^?[]\]&W-H==MU[L8N@7
MFP```SLKZ0,\"P"#-PP`M<?BAX%)F&?.AJ$'A2EE_XTFDY4V`)>7``"3AT?L
MF$,5ZP5'+H68P^_PK_.JBS'%DYHY`%:&XH7O\+^-(S![`9N'&0".![Z;([`+
M`.)K0FQ.PO&]8H7O\-^5(S"K`*J+"<V3FCD`Z;^!1\6UP46!25VW7NQBZ._P
MWY[B:T)L-;==<5;L_7>%:OURX1<3APH!HN`F_$KX3O12\(;D/I<6D:Z)LP4G
M`!.'B@`*EP5D%YD```,Y2=PJBA,&]/\7)0``$P5E>(,W"0`<XX%'[_!O]IL$
M!0!C7I``$X<*`0J7,P2'0)N']/\^E`-'A/\IXYWOEY<``(.WI]I.AM*%DI>(
M8^_P+^V%9Z$'BI>88X,W"0"YCP%'N>>%8A:1IF`&9.)T0GFB>0)ZXFIA88*`
MOH3]=P5GX1=!!SZ7,P0G`":&DP7P`B*%[_#_@475EY<``(.W!]6FAB*&DI>(
M8]*%[_!O^56W[_`?D$$1(N`7E````S0$TP;DEW8``).&9H&S!T0`B&,7E@``
M`S8&TI<E``"3A85L[_`?B1*4"&`"9*)@%S<``!,'1Z2!1[J&%Q8``!,&)NV7
M)0``DX4%;$$!;_!O\)>7``"#MZ?-EV8``).&)GP7E@```S8FS9*7B&.7)0``
MDX5E9V_P_X-=<2;\^7*)9(;DHN!*^$[T$X>$`1:1"I>7F0``@[DIQX.W"0`<
MXX%'[_`OZ/EWH1>3A@0"OI8SA"8`!68JAY<G``"3AT=FER8``).&1F8%!H5%
M(H7O\&_]_77!%9.'!`*NE[.$)P`BA05FIH7O\._=&P0%``%)8T\$`!L%%`#O
M\,_/*HD!R2*&IH5*E._P[^`C``0`B6?A!XJ7F&.#MPD`N8\!1YGKB6(6D:9@
M2H4&9.)T0GFB>6%A@H#O\`_\B;>%9OUW47']<I.'1_<3AP8)HO&F[<KI8O&&
M]<[ETN%6_5KY7O5F[6KI/I<6D2Z$LP4G`!.'A@@*EQ><```#/"RY*HF#-PP`
M'..!1Q<E```3!85;[_#?G*J$DP7P`DJ%[_#/X2'%%R4``!,%Y5K*A>_PW[M*
MA85GDX>'"(J7F&.#-PP`N8\!1V.6!Q2%8A:1KG`.=.YD3FFN:0YJZGI*>ZI[
M"GSJ;$IM;6&"@"*%[_#OWY<E``"3A257[_`ONBJ$7=&%9_UYX1D3AP<)3I>S
M"2<`$X<'"9.'!PF*EX5J?7JSC%=!@T<$`!,*BO=2EY<K``"3B^M3%RL``!,+
MZU,S"B<`R<N1Q**%)H7O\"_/-<4BA>_PK[F3!_7_HI<JC9,&\`)C:/0`,:@C
M@`<`_1=C!O0``\<'`.,)U_XBA>_P#[<JC4J%[_"/MFJ5!07C?57QA45*B-Z'
M(H?:A@5F3H7O\._@TH5.A>_P;\0!Z8.GC/B]9B%G]8]CC^<"ER4``).%I4H!
M1>_PCZTJA.,.!>R#1P0`K?N1Q(/'!`";AR?]F<<%31<D```3!*1%8;^#QQ0`
MZ=?]MX5%3H7O\$^S7?W.A1<E```3!45%[_!?IDZ%[_#OS56U[_"/WD$1DP7P
M`B+@!N0JA._PC\\9P1,$%0`BA0)DHF!!`6_P;\MY<85G_7)*Z`;T(O`F[!.'
MAP`6D1>9```#.>F;"I>#-PD`'..!1TW!@T<%`*J$R<_O\"^H$P85`(5G*H1C
M[\<*?7=A%\$'NI<SAR<`IH4ZA>_P+[F3!_3_JI>3!O`"8VCU`!&H(X`'`/T7
M8X:G``/'!P#C"=?^?76%9V$5P0>JES.$)P"3!?`"(H7O\(_%#<UC8J0&?76%
M9V$5P0>JES.%)P#O\`_!A6>A!XJ7F&.#-PD`N8\!1Z'GA6(6D:)P`G3B9$)I
M16&"@(5GH0>*EYAC@S<)`+F/`4>=XX5B%I&B<`)TXF1":1<E```3!<4Q16%O
M\"^\(P`%`'&_`45MM^_P3\PY<2+X)O1*\$[L!OR7E```@[1$C)Q@/N2!1T``
M%RD``!,)23*7F0``@[G)BZ*%2H7O\$_O%<$21X.W"0`.![J7F&>8XV77F&NA
M!YCC;?^BA4J%[_`O[67Q%RD``!,)B2^7F0``@[D)B**%2H7O\(_K%<$21X.W
M"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_!OZ67Q%RD``!,)22R7F0``@[E)
MA**%2H7O\,_G%<$21X.W"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_"OY67Q
M%RD``!,)B2F7F0``@[F)@**%2H7O\`_D%<$21X.W"0`.![J7F&>8XV77F&NA
M!YCC;?^BA4J%[_#OX67Q%RD``!,)22:7B0``@[G)?**%2H7O\$_@%<$21X.W
M"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_`OWF7Q%RD``!,)B2.7B0``@[D)
M>:*%2H7O\(_<%<$21X.W"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_!OVF7Q
M%RD``!,)21B7B0``@[E)=:*%2H7O\,_8%<$21X.W"0`.![J7F&>8XV77F&NA
M!YCC;?^BA4J%[_"OUF7Q%RD``!,)"1V7B0``@[F)<:*%2H7O\`_5%<$21X.W
M"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_#OTF7Q%RD``!,)21J7B0``@[G)
M;:*%2H7O\$_1%<$21X.W"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_`OSV7Q
M%RD``!,)B1>7B0``@[D):J*%2H7O\(_-%<$21X.W"0`.![J7F&>8XV77F&NA
M!YCC;?^BA4J%[_!ORV7Q%RD``!,)20J7B0``@[E)9J*%2H7O\,_)%<$21X.W
M"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_"OQV7QHH47)0``$P7E$._PK\:J
MA1G%%R4``!,%Y0WO\&_FHH47)0``$P6%$._PS\2JA1G%%R4``!,%!1'O\(_D
MHH47)0``$P4E$>_P[\*JA07-%R4``!,%I0#O\*_B(F><8+F/`4>IXT)TXG"B
M=`)YXFF7)0``DX6E$!<E```3!:4$(6%O\`_@HH47)0``$P6E#>_P;[ZJA7G1
M%R4``!,%I03O\"_>9;_O\,^6`1$BZ`;L%X0```,T)%=,`!<E```3!84"'&`^
MY(%'[_#ONA7!@T<%``%%B<>3AP?],S7P`")G'&"YCP%'F>?B8$)D!6&"@`%%
M];?O\.^1'7$&["J.%X4```,U158(81,#@0(N]#+X-OR^Y+K@PNC&[)>'``"#
MMX=0FH9RAH5%F&,ZY`%'&N#OX#_F$P7P#^_@O^%9<:+PP7)!9,[DTN!F[(;T
MINS*Z%;\6OA>]&+P$P>$`!:1"I>7C```@[PL3(.W#``<XX%'"4:!12J*[^#?
M\9,)]?\3U_E#09.SA^D`PA?!DYF/LXGY0&/'"0K!=,$4DP<$`<%KII?]6K.$
M)P"A"QU,%XD``!,)Z21!>P%&SH52A>_@?^UC"%4)7H:FA5*%[^"?^@$E8PI5
M!V-SK`9A%3.$I`!C=I0`H:A]%&-JE`0A1LJ%(H7OX#_G9?G!=T%GP1=!!SZ7
MLP<G`#,%]$!.E<%GH0>*EYAC@[<,`+F/`4>IX\%B%I&F<`9TYF1&::9I!FKB
M>D)[HGL"?.)L96&"@-J9XYUI]WU5X;<7)0``$P7E]._PW^H7)0``$P4E\^_P
M'^KOX'_[01$&Y._@_\@!)>_@G_01P0AAHF!!`8*`.7$F]$KP!OP7B0```SDI
M.JJ$3``7)0``$P5E\8,W"0`^Y(%'[_"OG1W%(OB#1P4`*H2-PZ:%[^!?T!W-
M(F>#-PD`N8\!1]'C0G3B<*)T`GDA88*`0G0B9X,W"0"YCP%'IH47)0``$P6%
M[+WCXG"B=`)Y(6%O\&^Y)H5.[._@_\"JB2*%[^!_P$Z5"07OX/_`(HB7)P``
MDX<'UR:'ER8``).&9M=]5H5%*H3OX!_J(F>#-PD`N8\!1Y'KHH7B:4)T%R4`
M`!,%I>95MT[L[^#_["+X3NSOX'_LEX<``).'IPIE<8.X!P$#N(<!D'.4=YA[
MG'_*^L[VTO(&YR+C%XH```,ZZBH#,PH`&OX!0Q<C```3`V/C$PG!`;[\ER<`
M`).'!^.JB1KP/OP7(P``$P,CRY<G``"3AR?BRH47)0``$P6%RAKT`OC&Z,+L
MLO"V]+KXON""Y._PKXH1Q8-'!0`JA&.4!QZF_M;N[^`_L0$E[^#?W&,.!10`
M86,+!!0BA>_@W[`&!04%[^!?L0-'!`"JA*J*%</:ZA<K```3"\O<)H7:AGU6
MA47OX%_:`T<4`(D$!01U]U9KA`@7)0``$P4ET2&@B&2A!`W!RH7O\$^#*H1M
MV8-'!0#UU^_P+XU]T2*%[^"_RBJ$&>T$$(!@`<R#1P0`8XP'#"*%[_`OBUWM
M@&2A!'7T(H7OX%^HJH16A>_@WZ>IG)N$1$`FA>_@'ZC6B)<G``"3AZ>^%R@`
M`!,(*-0BAY<F``"3A@;4?5:%1:J*[^"_T),%`!Q6A>_@'\+]5V,8]0#OX'^F
M'$%%1V.6YPP,`5:%[^!_QBJ$&>7*1[UF$6?UCV.`YPJ7AP``@[<G%X.V"0"(
M8U:'%R8``!,&IM.%1>_@G\F!1')W@S<*`+F/`4=CG0<NNF`:9/9J5GFV>19Z
M)H7V=%EA@H`BA>_@_[PJA*$$XP,%\C6_`40EOV)U)!@9R<J%[^"?\@'%@T<%
M`(WCB&2A!'WU-47:ZN_@_YJJA*J*%R0``!,$9,03!S`%6;WOX)^X*H1IW>_@
M'Y@&!04%E;W:ZFI+[^`_EIL'!0!C!OL$5FN)OQ>'```#-R<,@[8)``AC%R8`
M`!,&QL16AX5%[^"?OH&_[_"?RW)W@S<*`+F/`4=CF`<D(H4:9+I@5GFV>19Z
M66%OX#^RRD?>YN+B$P<`')/W]Q]CAN<`5FNV:Q9LU;TFA>_@/Y'*A:J$%R4`
M`!,%I<COX'_FJH5C#P40`[4)`._PK\.JBV,(!1!>A>_@GXT;"P4`C4=CV&<#
M$P7+_Y<E``"3A>7%7I7OX-^@">V11V,'^QB;![O_WI<#QP<`DP?P`F,.]Q;*
MA1<E```3!<6G[^"?X&'%@T<%`.G#$P<``V..YPJ7)0``DX6%KQ<E```3!86E
M[^`?_^_@WYHJB)<H``"3B&C/ER<``).'YYU6AY<F``"3AL;!?5:%12:%[^!_
ML'U9Q4D7+```$PSLS)<K``"3BVN;%RL``!,+:\`EH._@7X4<06.7-P/OX+^5
M!20JB&+@HHC>AU:'VH9]5H5%)H7OX#^LDP4`'":%[^"?G>,()?U6A>_@_YFF
MA1<E```3!064[^`?]B:%[_`?M59KMFL6;/F[@[L)`,6]@45>A>_@7ZXJB1W=
M[_!_GZJ)XTL%\I,%9?\!1DJ%[^"_DQ,+`1`91MJ%2H7OX-^@F4=C'O4(`R<!
M$+='04.3AP<PXQ/W\`-72P"19Y.'AU3C'/?N`4:3A>G\2H7OX-^/(`(3!H`"
MHH5*A>_@_YR3!X`"8Q[U!)<H``"3B"B^(HB7)P``DX>'C%:'ER8``).&9J]]
M5H5%)H4C"`$2[^#?GB6_@[F)`.."">A.A>_@S_&-1^/\I^9Q%9<E``"3A06K
M3I7OX'^%XQ(%YLZ+N;T7)0``$P4EJN_PGX[:ZM[FXN+OX)^?IO[6[MKJWN;B
MXN_@OYXY<2+X%X0```,TI.%*\$[L!OPF]%+HLP=$`(1CDPE!`!>)```#.6G=
M@\<$"\Z%%R4``!,%A88#-PD`.N0!1Z.(]`KOX)_`&<4#1P4`DP<0`V,+]Q+O
M\"_-LP=$`(1C)H6-1@5&ER4``).%):;OX*_MJH0=P1QI,P=$``ACC&,7)@``
M$P8&I>_@#^V<:(QCW$43EY<"8T8'$+,'1`"(8XU&!4:7)0``DX5%H^_@S^FJ
MA!>*```3"NK:#<'.A1<5```3!25X[^!_N"J&><&<:#,'1``(8XQC[^`/Z+,'
M1`"$8P5&ER4``).%Q9\FA>_@K]NJA1<F```3!D:@)H7OX*_E$I0<8,Z%%Q4`
M`!,%A7*CB`<*[^"?LR,XJ@`JA#G%DP4`'"*%[^`O^1L'%0"%1V/PYP+%1V,-
M]0"#-XH`JH8BAHQC%R4``!,%19[OX,_](F>#-PD`N8\!1['KXG!"=*)T`GGB
M:4)J(6&"@`,UB@#O\'^;(SBJ`"J$7?$7)0``$P5%F._@3_J#1Q4`XXH'[-FU
M`S>*`)QH#&.(8^_@O^8UO[,'1`"(8^_@#_7]M>_@OX-Y<2+P)NQ*Z`;T%XD`
M``,YR<.#-PD`/N2!1ZJ$[_"/I9,%\`(JA._@#_,9P1,$%0`BA>_@3^\JA$P`
M%Q4``!,%Q6SOX)^E`<V#1P4`B<L3!P`#8X;G`('$@\<$`(GO(F>#-PD`N8\!
M1Y7OHG`"=.)D0FE%88*`$4:7%0``DX7E>"*%[^!/QF'](F>#-PD`N8\!1XGK
M`G2B<$)I)H7B9$5A;^`?L._@+_D3`0'4(SB!*B,\$2HC-)$J(S`A*R,\,2DC
M.$$I%X0```,T)+@T`,%N?5\<8",T\2B!1Y,(A0.3`H4'-H@37P\"MP__`)..
M#O`#M@@`00BA")-5!@(3%X8!DQ.&`)-7A@(37H8`DU2&`Q.3A0$S=^<!L_/S
M`;/WUP$S9W<`,W[>`<6/,W/C`:(%,V?'`1M6A@&SYV<`L_7U`5&/S8\C..C^
M(SSX_N.2$OO]5<9_9G\*9^)N`GXB<\)X8GB&8Y.$!B"!D1&@LH.P8IQBNH*A
M!K&/L\?W`;/'UP$3EQ<`_8-=CVV/N/[ZC_*.%H\:CD:#PH@>B..9EOR#/@4`
MHF\#.`4!`S.%`(,XA0$#/@4"-X>"6A,'EYF3U[X!$Y9>`%V.NI\37R,`DQ?C
M`6V.\I^S1A@!L^?G`;/V9@!^EL)O,_^W`+/&%@$VEK-&Z`%MCK/VU@&ZGY,2
M5@"35+8!QI^SQ@8!_I:S[Y(`$]DN`).3[@'^EN)OL^,C`;/'=P#QC[J?[8ZS
MQ^<!PI^3E%8`$]FV`9,2Y@'^EPF"@G^SXL(`,^8D`;*7,\93`+J?L_.S`'6.
M[8]^GS-&=@"3E%<`$]FW`9.?Y@%ZEHF"(G^S[]\`L^8D`3:6L\;R`6V.L_*R
M`/V..I\>GY,45@`36;8!L\96`).3YP&)@[/C\P#ZEK/G)`&^EC/_M@#"=K/'
M?P#QC[/_OP"ZEI:6DQ1?`!-9OP&SQ_<!MI>SYB0!MI>3$N8!"8*SXL(`,_:W
M`.)WL\93`+/VY@&S\[,`NI?^EY,45@`36;8!L\9V`+Z6L^<D`;Z6DQ_O`1-?
M+P"S[^\!,_^V`(9FL\?R`?&/L_*R`+J6GI:3%%\`$UF_`;/'5P"VE[/F)`&V
MEY,3Y@$)@K/CPP`S]K<`IF>SQG\`L_;F`;/_OP"ZEY:7DQ16`!-9M@&SQO8!
MOI:SYR0!OI:3$N\!$U\O`+/BX@$S_[8`QF:SQU,`\8^S\[,`NI;^EI,47P`3
M6;\!L\=W`+:7L^8D`;:7DQ_F`0F"L^_/`#/VMP#F9[/&\@&S]N8!L_*R`+J7
MGI>3%%8`$UFV`;/&5@"^EK/G)`&^EI,3[P$37R\`L^/C`3/_M@"&=K/'?P#Q
MC[/_OP"ZEI:6DQ1?`!-9OP&SQ_<!MI>SYB0!MI>3$N8!"8*SXL(`,_:W`*9W
ML\93`+/VY@&S\[,`NI?^EY,45@`36;8!L\9V`+Z6L^<D`;Z6DQ_O`1-?+P"S
M[^\!,_^V`,9VL\?R`?&/L_*R`+J6GI:3%%\`$UF_`;/'5P"VE[/F)`&VEY,3
MY@$)@K/CPP`S]K<`YG>SQG\`L_;F`;/_OP"ZEY:7DQ16`!-9M@&SQO8!OI:S
MYR0!OI:3$N\!$U\O`+/BX@$S_[8`BF:SQU,`\8^S\[,`NI;^EI,47P`36;\!
ML\=W`+:7L^8D`;:7DQ_F`0F"L^_/`#/VMP"J9[/&\@&S]N8!L_*R`+J7GI>3
M5+8!DQ-6`+/&5@`3&>\!OI837R\`L^>3`,IC,V_I`;Z6L\?O`>V.L_^_`+J3
M\8^>DI/4M@&SQ_<!DY-6`+/CDP"6E^IDDQ+F`0F"L^+"`)Z7[8\S1E\`NI0S
M?[\`$]FW`76.DY-7`*:?,T;F`;/C(P&S\[,`?I:3G^8!B8(>EK/OWP`*>;-T
MM@"SQO(!_8ZS\K(`DY-4`)/9M`$ZF3/'5@"SYC,!DY/G`8F#L^/S`$J?L\=_
M`.V.>I>QCRIV,P_7`#?WV6X3!Q>ZLWF_`!/9N0$ZEI.660`6ENV/L^8F`;*7
M[8Z^EI.2Y`'*=XF`L^*2`#/YM@`SQE,`L_^_`)-4N0&ZES-/Y@$3%ED`,W^_
M`/Z718[ZEVV./I:3G^D!ZG>3V2D`L^\_`;-TM@`SS_(!L_.S`)/9M`&ZES-/
MWP"3EE0`,W^_`)Z7L^8V`?J7[8Z^EA,?Z0&.9Q-9*0`S;R\!L_.V`#/)[P&S
M^;(`NI>S0LD`$]FS`1.64P"S\K(`SI<S9B8!EI=MCCZ6DY+D`:YGB8"SXI(`
M,TE?`+-TM@"S^;\`NI>S3]D`$]FT`9.65`"S_[\`SI>SYB8!_I?MCKZ6DY_C
M`<YGD],C`+/O?P`SR?(!L_.V`+-YOP"ZES-/R0`3V;,!$Y93`#-_OP#.ES-F
M)@'ZEVV./I83G^0![F>)@#-OGP`SR>\!LW2V`+/YL@"ZE[-"V0`3V;0!DY94
M`+/RL@#.E[/F)@&6E^V.OI:3DN,!CG>3TR,`L^)R`#-)7P"S\[8`L_F_`+J7
MLT_)`!/9LP$3EE,`L_^_`,Z7,V8F`?Z7;8X^EI.?Y`&N=XF`L^^?`#/)\@&S
M=+8`LWF_`+J7,T_9`!/9M`&3EE0`,W^_`,Z7L^8F`?J7[8Z^EA.?XP'.=Y/3
M(P`S;W\`,\GO`;/SM@"S^;(`NI>S0LD`$]FS`1.64P"S\K(`SI<S9B8!EI=M
MCCZ6DY+D`>YWB8"SXI(`,TE?`+-TM@"S^;\`NI>S3]D`$]FT`9.65`"S_[\`
MSI>SYB8!_I?MCKZ6DY_C`9)GD],C`+/O?P`SR?(!L_.V`+-YOP"ZES-/R0`3
MV;,!$Y93`#-_OP#.ES-F)@'ZEVV./I83G^0!LF>)@#-OGP`SR>\!LW2V`+/Y
ML@"ZE[-"V0`3V;0!DY94`+/RL@#.E[/F)@&6E^V.OI:3DN,!TF>3TR,`L^)R
M`#-)7P"S\[8`L_F_`+J7LT_)`!/9LP$3EE,`L_^_`,Z7,V8F`?Z7;8X^EI.?
MY`'R9XF`L^^?`#/)\@&S=+8`LWF_`+J7,T_9`!/9M`&3EE0`,W^_`,Z7L^8F
M`?J7[8Z^EA.?XP&2=Y/3(P`S;W\`,\GO`;/SM@"S^;(`NI>S0LD`$]FS`1.6
M4P"S\K(`SI<S9B8!EI=MCCZ6DY+D`;)WB8"SXI(`,TE?`+-TM@"S^;\`NI>S
M3]D`$]FT`9.65`"S_[\`SI>SYB8!_I?MCKZ6DY_C`=)WD],C`+/O?P`S^;8`
ML\/R`;-YOP"ZES//PP"34[D!$Q99`#-_OP#.ES-F=@!MCOJ7,X_'`).3Y`'R
M=XF`L^.3`#/&?P"S=+\`L_*R`+J7L8[MCI/9M`&6EY.25`"VE[/F,@&VEQ,6
MZ0&69A-9*0`S9B8!,\G#`+/RMP"S_[\`LT?I`;J6D]FR`?Z6$YE2`+/_MP`S
M:3D!_I;*EA.?Y`&)@#-OGP`W]\8CLW2V`/U7]8VV9H&3"@<3!\?-LW__`#-F
MY@$S^?0!NI8S=E8`L_/S`+:3D]FU`3-F)@$3F54`'I:S8SD!'I:S<_8`DY;B
M`59FD](B`+/F5@"S\O8`,V_?`#/Y7P`ZEC-_OP"RE)/9LP$S;R\!$YE3`":?
MLV0Y`1.6Y0$FGXF!]F1-CK-U]@#1CC-__P`S^;(`L_9V`+J4_I236;\!L^8F
M`1,97P"FEK-D.0$3FN,!D]\C`*:6EG2S;_H!L_/_`#-F]@']CC/Y=0"ZE#-V
MY@&FDC-F)@&3E%8`$]FV`;/D)`$6EI,9[P$FEA-?+P"V=#/OZ0&S<O\`L^_O
M`7V.,_E3`+/_WP"ZE+/O+P&NE!,95@"36;8!DY7F`8F"U8VSAI\`LV\Y`?Z6
MUG^S]/4`,V^_`/V.,_F2`+J?,W_/`#-O+P'^DQ.95@"3V;8!DQ_F`0F"L^_/
M`#,&?P`S;SD!>I9V?[/S_P"SY?4!?8XS^70`.I_UC;/E)0'ZDA,95@"36;8!
M$Y_F`8F",V_?`+.&50"S93D!KI::9;-R_P"S[^\!_8XS^5,`NI6S_\\`L^\O
M`:Z4$YE6`)/9M@&3%>8!"8+1C3.&GP"S;SD!?I:Z;[/T]0`S;[\`?8XS^9(`
MNI\S?]\`,V\O`?Z3$QE6`)-9M@&3G^8!B8*S[]\`LP9_`#-O.0'ZEEIOL_/_
M`+/E]0']CC/Y=``ZG_&-L^4E`?J2$YE6`)/9M@$3'^8!"8(S;\\`,X95`+-E
M.0$NEOIELW+_`+/O[P%]CC/Y4P"ZE;/_WP"S[R\!KI03&58`DUFV`9.5Y@&)
M@M6-LX:?`+-O.0'^EII_L_3U`#-OOP#]CC/YD@"ZGS-_SP`S;R\!_I,3F58`
MD]FV`9,?Y@$)@K/OSP`S!G\`,V\Y`7J6.G^S\_\`L^7U`7V.,_ET`#J?]8VS
MY24!^I(3&58`DUFV`1.?Y@&)@C-OWP"SAE4`LV4Y`:Z6VG6S<O\`L^_O`?V.
M,_E3`+J5L__/`+/O+P&NE!.95@"3V;8!DQ7F`0F"T8TSAI\`LV0Y`2:6^G2S
M__4`,V^_`'V.,_GR`3-_WP"ZE#-O+P&>E!,95@"36;8!DY/F`8F"L^/3`+,&
MGP"S9#D!'FDS__,`L^5U`*:6\8VS].\!.IG]CA:9Q8V3F58`$]JV`9-2)@"3
M%.8!RI4^:;/D5``SYDD!L_+T`+*5,^:3`'6.L_/U`#J9LW5?`'Z9DYE3`!/:
MLP%-CI/?)@"3E>8!2I:SYDD!L^7U`3:6L^:T`+-T]@!>9K/_]0`S^?(!L_9V
M`#J6>I:SYB8!$Y]4`!/9M`$S;R\!LI9^:1.6XP&3TR,`,V9V`+-S]@#ZEM&-
M_8XS^G\`Y8TZF1.?5@"3V;8!%IFSY44!LV(_`<J5$]\D`!.9Y`&S9.D!'G^S
M\O(`EI5%CK/R]``S^?4`,_I3`'6..I^36;D!$Q=9`'Z?,V9&`;-O-P%ZEI.9
MY@$3WR8`,^_I`;/&Y`&S__\`K8XWMY@ROG6RGPH'$P=G';/Y_P"3U+D!NI43
MEED`GI7]CD6.DQ/I`1-9*0"SXR,!?8ZNEK.%Q@`S1G\`,T;V`=Y_L_3U`!/9
MM`&ZGY.65`"6GWV.L^8F`?V.?I8VEI.?Z0'^=I/9*0"S[S\!,WGV`+/"\P&S
M>?\`NI8SS[(`DU*Y`9,560`S?_\`SI:SY54`^I;]C;:5$Y_D`8,V`2")@#-O
MGP"SPN\!L_3U`+/S\P"3V;0!NI:SPL(`$Y94`+/R\@">EC-F-@&6EGV.-I:3
M$ND!@S:!(!-9*0"SXB(!LW/V`#-)7P"S^?\`NI:S3[D`$]FS`9.54P"S__\`
MSI:SY24!_I;]C;:5DY_D`8,V`2&)@+/OGP`SR?(!L_3U`+-Y_P"ZEC-/R0`3
MV;0!$Y94`#-__P#.EC-F)@'ZEGV.-I83G^,!@S:!(9/3(P`S;W\`,\GO`;-S
M]@"S^?(`NI:S0KD`$]FS`9.54P"S\O(`SI:SY24!EI;]C;:5DY+D`8,V`2*)
M@+/BD@`S25\`L_3U`+/Y_P"ZEK-/R0`3V;0!$Y94`+/__P#.EC-F)@'^EGV.
M-I:3G^,!@S:!(I/3(P"S[W\`,\GR`;-S]@"S>?\`NI8S3[D`$]FS`9.54P`S
M?_\`SI:SY24!^I;]C;:5$Y_D`8,V`2.)@#-OGP`SR>\!L_3U`+/Y\@"ZEK-"
MR0`3V;0!$Y94`+/R\@#.EC-F)@&6EGV.-I:3DN,!@S:!(Y/3(P"SXG(`,TE?
M`+-S]@"S^?\`NI:S3[D`$]FS`9.54P"S__\`SI:SY24!_I;]C;:5DY_D`8,V
M`22)@+/OGP`SR?(!L_3U`+-Y_P"ZEC-/R0`3V;0!$Y94`#-__P#.EC-F)@'Z
MEGV.-I83G^,!@S:!))/3(P`S;W\`,\GO`;-S]@"S^?(`NI:S0KD`$]FS`9.5
M4P"S\O(`SI:SY24!EI;]C;:5DY+D`8,V`26)@+/BD@`S25\`L_3U`+/Y_P"Z
MEK-/R0`3V;0!$Y94`+/__P#.EC-F)@'^EGV.-I:3G^,!@S:!)9/3(P"S[W\`
M,\GR`;-S]@"S>?\`NI8S3[D`$]FS`9.54P`S?_\`SI:SY24!^I;]C;:5$Y_D
M`8,V`2:)@#-OGP`S^?4`L\3O`;/Y\@"ZEK/"Q`"35+D!$Q99`+/R\@#.ED6.
MEI9]CC:6DY3C`8,V@2:3TR,`L^1T`+-"GP"S<_8`L_G_`+J6L\^R`)/2LP&3
ME5,`L___`,Z6L^55`/V-_I:SC[8`DQ+I`8,V`2<362D`L^(B`;/%5``S^?\`
M,W__`)-9N0&ZEK&-$Q99`/V-^I8S9C8!?8ZNEK.%Q@`3G^,!`S:!)Y/3(P`S
M;W\`L\;B`;/S]0#]C#J6L\;V`?V.)I:3V;,!DY13`#:6L^8T`3:6@S8!*),?
MZ0$362D`L^\O`;J6LT3_`3-W]@#VEK/R\@`SQK0`?8Z3%5<`DUZW`9:6LI8S
MYM4!DY7C`9/3(P"REK/E=0#]CCJ3,P;/`3.'!0&SA1\!?8\4X?V-LW;S`/&/
M&.D<\13E#.T#-X$H'&"YCP%'A>.#,($K`S0!*X,T@2H#.0$J@SF!*0,Z`2D3
M`0$L@H#OT(_201$3!0`(!N3OT,^AMW9=3#=WZ6&W)45GDX45,(8&-U8R$`8'
M#.&3AN;/ET4``(.UI4,3!F9'$P<''PSE%.D0[1CQ(S0%`B,X!0(C+`4&HF!!
M`8*`.7$B^";T2O!6Y`;\3NQ2Z!AUDQ<V`!1YNI>"%X&3,[?G`*J$NI8H71-7
MU@$VEYSTF/@RB2Z$DXJ$`S'MDP?P`V/<)PD;"0G\&UII`)L)&@":":*9HH43
M!@`$5H7OT$^I$P0$!":%[^#?S>,5-/\;&FH`.PE)04J&SH56A>_03Z<CK"0'
MXG!"=*)T`GGB:4)JHFHA88*`DPD`!+N'J4"^B6-*]@(;B@D`DXJ$`U*&HH56
ME>_0[Z.\7!,'``2[AOD`M-SCD>;\)H4["3E!4I3OX%_'K;>RB?FWHHEQOWEQ
M(O`F[%+@!O1*Z$[D@[F%`A.*A0.3!@#X$]8Y`!-V]@,S!\H``[D%`Y,'%@`C
M`-<`$P>``RZ$JH0%)F-7]Q(3!P`$$9^11C,%^@!C==<4B4=C>?<28Q0'$B*%
M[^"_P!,&@`.!15*%[]#/KY-6"0$35XD`D_;V#Z(&FU>)`1-W]P]"!]6/$WGY
M#V()V8\;UHD!D]8)`0(6L^<G`1/7B0"3]O8/HA;1CQ-W]P]"%]6/XAG9C[/G
M-P$\^"*%[^"_NAQ@(H7A@R.`]``<8,&#HX#T`!Q@H8,C@?0`'&"C@?0`'&3A
M@R."]``<9,&#HX+T`!QDH8,C@_0`'&2C@_0`'&CA@R.$]``<:,&#HX3T`!QH
MH8,CA?0`'&BCA?0`'&SA@R.&]``<;,&#HX;T`!QLH8,CA_0`'&RCA_0`''#A
M@R.(]``<<,&#HXCT`!QPH8,CB?0`''"CB?0``G2B<.)D0FFB:0)J16%OT.^2
M$P>``SL&QT"!13,%^@#OT,^>Q;TC``4`X;TC``4`HP`%`'D7"07C!0?L[;<C
M``4`HP`%`",!!0"C`04`<1>)1Q$%XV7WZM&_EV8``(.V)D)OP+__````````
M`0`"```````E<R\E<P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB
M;V]T7T1Y;F%,;V%D97(``````$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````&5X
M90``````+W!R;V,O)6DO)7,``````"X`````````4$%27U1%35``````````
M`%!!4E]04D]'3D%-10`````Z`````````"\`````````)7,E<R5S``!015),
M-4Q)0@``````````4$523$Q)0@!015),-4]05```````````4$523$E/``!0
M05)?24Y)5$E!3$E:140`4$%27U-005=.140``````%!!4E]#3$5!3@``````
M``!005)?1$5"54<`````````4$%27T-!0TA%`````````%!!4E]'3$]"04Q?
M1$5"54<``````````%!!4E]'3$]"04Q?5$U01$E2`````````%!!4E]435!$
M25(```````!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@``````
M````,0````````!L<V5E:R!F86EL960`````<F5A9"!F86EL960``````$Q$
M7TQ)0E)!4EE?4$%42`!365-414T``"]T;7``````55-%4@````!54T523D%-
M10``````````)3`R>`````!P87(M`````"5S)7,E<R5S```````````E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*````````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES
M('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R
M871I;VXI"@```````%!!5$@`````<&%R;``````N<&%R`````'-H;W)T(')E
M860````````E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T
M96UP+25U+25U)7,``````````!@`````````<&5R;``````P`````````%!!
M4CHZ4&%C:V5R.CI615)324].`````#$N,#4Y````56YA8FQE('1O(&-R96%T
M92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV
M871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`
M`````````"UE````````+2T```````!435!$25(``%1%35!$25(`5$5-4```
M``!435```````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ
M*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*
M<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E
M=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#
M(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P
M86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@
M/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F
M:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68[
M"FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S
M:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@
M;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS
M965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE
M("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B
M=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*
M)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?
M=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$
M('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`[
M"G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*
M;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M
M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*
M1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@
M=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD
M("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N
M97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@
M)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^
M9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD
M>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@
M)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@
M7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*
M8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^
M+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W
M;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F
M:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?
M<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT[
M"FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@
M/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7
M:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]
M/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T
M7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B
M72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@
M/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?
M;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?
M7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G
M;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA
M;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R
M<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R
M7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#
M86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B
M)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M
M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G
M:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B
M*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H
M)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T
M<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T
M<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D
M;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D
M8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B
M3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I
M<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F
M<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N
M(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F
M+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER
M<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@
M)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM
M>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D
M9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH
M6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L
M("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A
M9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\
M<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C
M)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F
M=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE
M>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M
M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK
M.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*
M;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U
M;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U
M;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES
M='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M
M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ
M1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@
M;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN
M;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P
M+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A
M=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O
M+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D
M9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A
M73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C
M86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM
M>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2![
M"G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$
M4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER
M92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I
M;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R
M97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?
M34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T
M:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T
M87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T
M87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L
M("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%
M55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O
M8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M
M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@
M8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R
M"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD
M("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM0
M05)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA
M;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6
M*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R
M(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF
M("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I
M('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B
M=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`]
M(#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@
M)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]
M"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF
M="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE
M=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z
M.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*
M=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*
M<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I
M<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@
M)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W
M)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z
M("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P
M87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O
M<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R
M(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT
M<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE
M=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI
M)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G
M/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D
M<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q
M6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+
M6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY
M("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4
M*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I
M+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z
M("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A
M9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E
M860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L
M<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@
M*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<
M0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H
M+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D
M97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2
M.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET
M7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A
M+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N
M9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S
M?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F
M;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.
M0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@
M("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF
M;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE
M+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F
M8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME
M>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@
M*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>
M+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI
M('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M
M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D
M,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*
M;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE
M*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN
M=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL
M92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I
M;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A
M;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD
M=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH
M7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]6
M15)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L
M("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG
M+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H
M:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C
M:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*
M;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2![
M"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B
M)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H
M(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE
M*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@
M,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A
M8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S
M=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H
M95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D
M8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%
M(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R
M*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I
M.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@
M;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL
M87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H
M*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ
M2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q
M<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N
M:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH
M)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG
M('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#
M:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II
M<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X
M=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]
M*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY
M("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M
M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE
M3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI
M8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*
M?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I
M;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA
M;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N
M8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R
M7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE
M(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M
M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&
M:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D
M9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E
M<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O
M9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@
M6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A
M<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S
M<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@
M/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I
M(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L
M("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA
M;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H
M.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I
M97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E
M(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E
M<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,[
M"G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%
M<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T
M97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER
M92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I
M9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q
M=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(
M96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0[
M"G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V
M86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ
M571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@
M?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*
M979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R
M('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M
M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF
M;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$
M25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O
M=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@
M)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*
M979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM]
M.PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA
M;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U
M:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@
M/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]
M"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K
M*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D
M8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@
M/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D
M<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A
M73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@
M/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S
M:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H
M+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#
M2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I
M>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`[
M"G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O
M7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D
M9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD
M)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[
M7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.
M5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D
M,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D
M;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92([
M"G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L
M;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N
M86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM
M;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H
M)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]
M"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.
M04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE
M('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA
M;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T
M<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@
M*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O
M9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L
M("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US
M("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?
M97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D
M<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T
M<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*
M)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@
M(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I
M"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2([
M"B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@
M;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*
M<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM0
M05)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI
M;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M
M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z
M.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R
M.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]
M?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI
M;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P
M87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T]
M(#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141]
M(#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#
M2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O
M<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%2
M7R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[
M(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L
M971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF
M("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]
M"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U
M:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N
M9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I
M=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E
M>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)
M3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*
M9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N
M86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@
M)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D
M0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*
M)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D
M.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?
M15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R;'AS:2YC````
M``````!#04-(10``B:O-[P`````!&P,[!`$``!\```#8D/__L`8``&22__\<
M`0``DI+__S`!``"TDO__1`$``."2__]8`0``&I/__WP!```<D___D`$``,B3
M___\`0``(I3__R@"```HE?__@`(``-:6___@`@``O)?__R`#```6F/__1`,`
M`#Z8__]8`P``_)C__Y`#``#^F/__I`,``-2:___X`P``]IK__Q@$``#XF___
M7`0``%"?__^0!```GI___[0$``#BG___S`0```:A__\<!0``'J'__S@%``#V
MH?__D`4``-*F__\\!@``@JC__W0&```JJ?__Z`8``)2[__\@!P``Z+O__T`'
M``#$O/__>`<````````0``````````-Z4@`!?`$!&PT"`!`````8````0)'_
M_R(`````!P$`$````"P```!:D?__(@`````````0````0````&B1__\L````
M`````"````!4````@)'__SH`````0@X00H@$3H$"8L%"R$(.`````!````!X
M````EI'__P(`````````:````(P```"$D?__K`````!"#D!$@0*(!$R6$%*2
M"),*E`QFB0:5#F;)0M)"TT+40M5"UD+!1,A"#@!"#D"!`H@$B0:2"),*E`R5
M#I804,G2T]35UD26$$+61)((DPJ4#)801M)"TT+40M8`*````/@```#$D?__
M6@````!"#K`!1H@$B0:!`@)&"L%"R$+)0@X`0@L```!4````)`$``/*1__\&
M`0```$(.P`%$DPJ!`EB(!$;(4,%"TT(.`$(.P`&!`H@$DPI$B0:2"'*4#`)6
MU%0*R$+)0M)""U*4#$C(R=+42(@$B0:2")0,````7````'P!``"@DO__K@$`
M``!"#F!4B`2)!I((E`R!`I,*E0Z6$`+0"L%"R$+)0M)"TT+40M5"UD(.`$(+
M;I<2F!0"5@K70MA$"U37V$27$I@41M?81)<2F!1&UT+8````/````-P!``#N
MD___Y@````!"#E!$E0Y:#M`@B`2)!I((DPJ4#($"`GH*#E!"P4+(0LE"TD+3
M0M1"U4(.`$(+`"`````<`@``E)3__UH`````0@X00H@$2H$":,A"P5X.````
M`!````!``@``RI3__R@`````````-````%0"``#>E/__O@````!"#E!$B090
M#M!`@0*(!)((DPH"E`H.4$+!1,A"R4+20M-"#@!""P`0````C`(``&25__\"
M`````````%````"@`@``4I7__]8!````1@[P`68.\"&(!(D&D@B8%($"DPJ4
M#)4.EA"7$ID6FA@"8@H.\`%"P4+(0LE"TD+30M1"U4+60M="V$+90MI"#@!"
M"QP```#T`@``U);__R(`````0@X02(@$@0)0R$+!0@X`0````!0#``#6EO__
M`@$```!"#C!2#K`@D@B!`H@$B08"J`H.,$+!0LA"R4+20@X`0@M6"@XP0L%"
MR$+)0M)*#@!$"P`P````6`,``)27__]8`P```$(.0$J(!(D&D@B3"H$"`PH#
M"LA"P4+)0M)"TU(.`$0+````(````(P#``"XFO__3@````!"#B!$B`2!`GH*
MP4+(0@X`0@L`%````+`#``#BFO__1`````!"#F!"@1(`3````,@#```.F___
M)`$```!"#G!$B`1<#O"`!),*E`R9%H$"B0:2")4.EA"7$I@4`L(*#G!"P4+(
M0LE"TD+30M1"U4+60M="V$+90@X`0@L8````&`0``.*;__\8`````$(.$$*!
M`E#!0@X`5````#0$``#>F___V`````!"#D!&B0:2"($":(@$6@K(0L%"R4+2
M0@X`0@M"R%C!0LE"TD(.`$0.0($"B`2)!I((1`J3"@)"TT+(2@M"DPI$R--$
MB`23"J@```",!```7IS__]P$````2@Z0`UJ2"),*E`R!`H@$`FR)!I4.;I80
M8-8#\@`*P4+(0M5"TD+30M1$R4(.`$(+<@J6$%8+5)804-9BR=56R$+!0M)"
MTT+40@X`1`Z0`X$"B`2)!I((DPJ4#)4.EA!.EQ*8%$;60M="V$*6$)<2F!0#
M,`$*UD+70MA""P/@`-;7V$:6$)<2F!1$R=76U]A*B0:5#I80EQ*8%``T````
M.`4``(Z@__^P`0```$(.0$*(!%*2"),*@0*)!I0,`T8!"L%"R$+)0M)"TT+4
M0@X`0@L``#@```!P!0``!J+__Z@`````0@XP2(@$B0:2"($"`F(*P4+(0LE"
MTD(.`$(+8`K(0L%"TD3)0@X`1`L``#0```"L!0``((K__XH!````0@Y@3($"
MB0:(!)((DPH##@$*P4+(0LE"TT320@X`0@L`````````-````.0%```ZHO__
M:A(```!$#L`%6(@$@0*)!I((DPJ4#`,P$@K!1,A$R4321--$U$0.`$(+```<
M````'`8``&RT__]4`````$(.$$:!`@)(P4(.`````#0````\!@``H+3__]P`
M````0@Y`3H@$B0:2")4.@0*3"I0,`G8*P4+(0LE"TD+30M1"U4(.`$(+-```
M`'0&``!$M?__L@$```!"#C!,B`2)!I0,@0*2"),*`TP!"LA"P4+)0M)"TT+4
M0@X`1`L`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````$`````````[0(````````!````````
M`/T"`````````0`````````'`P```````"``````````V*T````````A````
M``````@`````````&0````````#@K0```````!L`````````"``````````:
M`````````.BM````````'``````````(`````````/7^_V\`````V`(`````
M```%`````````$`-````````!@````````#(`P````````H`````````L00`
M```````+`````````!@`````````%0````````````````````,`````````
M4+`````````"`````````%@%````````%``````````'`````````!<`````
M````,!4````````'`````````"`3````````"`````````!H!P````````D`
M````````&``````````>``````````@`````````^___;P`````!```(````
M`/[__V\`````P!(```````#___]O``````(`````````\/__;P````#R$0``
M`````/G__V\`````"P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"E!!4BYP;0H`````````````````````````
M````````````````````````````````````````````````````````````
M__________\``````````)`:````````D!H```````"0&@```````)`:````
M````D!H```````"0&@```````)`:````````D!H```````"0&@```````)`:
M````````D!H```````"0&@```````)`:````````D!H```````"0&@``````
M`)`:````````D!H```````"0&@```````)`:````````D!H```````"0&@``
M`````)`:````````D!H```````"0&@```````)`:````````D!H```````"0
M&@```````)`:````````D!H```````"0&@```````)`:````````D!H`````
M``"0&@```````)`:````````D!H```````"0&@```````)`:````````D!H`
M``````"0&@```````)`:````````D!H```````"0&@```````)`:````````
MD!H```````"0&@```````)`:````````D!H```````"0&@```````)`:````
M````D!H```````"0&@```````)`:````````D!H```````"0&@```````)`:
M````````D!H```````"0&@```````/"M````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````1T-#.B`H1&5B
M:6%N(#$S+C(N,"TR*2`Q,RXR+C``05(```!R:7-C=@`!2`````00!7)V-C1I
M,G`Q7VTR<#!?83)P,5]F,G`R7V0R<#)?8S)P,%]Z:6-S<C)P,%]Z:69E;F-E
M:3)P,%]Z;6UU;#%P,```+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU+F)U
M:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T
M<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA
M+G!L=``N=&5X=``N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YP
M<F5I;FET7V%R<F%Y`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC
M`"YD871A`"YG;W0`+F)S<P`N8V]M;65N=``N<FES8W8N871T<FEB=71E<P``
M````````````````````````````````````````````````````````````
M````````````````````````"P````$````"`````````'`"````````<`(`
M```````A`````````````````````0```````````````````!,````'````
M`@````````"4`@```````)0"````````)`````````````````````0`````
M```````````````F````!P````(`````````N`(```````"X`@```````"``
M```````````````````$````````````````````-````/;__V\"````````
M`-@"````````V`(```````#L``````````4`````````"```````````````
M`````#X````+`````@````````#(`P```````,@#````````>`D````````&
M`````@````@`````````&`````````!&`````P````(`````````0`T`````
M``!`#0```````+$$```````````````````!````````````````````3@``
M`/___V\"`````````/(1````````\A$```````#*``````````4`````````
M`@`````````"`````````%L```#^__]O`@````````#`$@```````,`2````
M````8``````````&`````@````@```````````````````!J````!`````(`
M````````(!,````````@$P```````!`"````````!0`````````(````````
M`!@`````````=`````0```!"`````````#`5````````,!4```````!8!0``
M``````4````5````"``````````8`````````'D````!````!@````````"0
M&@```````)`:````````L`,``````````````````!``````````$```````
M``!^`````0````8`````````0!X```````!`'@```````*HM````````````
M```````$````````````````````A`````$````"`````````/!+````````
M\$L```````!X00``````````````````"````````````````````(P````!
M`````@````````!HC0```````&B-````````!`$```````````````````0`
M``````````````````":`````0````(`````````<(X```````!PC@``````
M`*P&```````````````````(````````````````````I````!`````#````
M`````-BM````````V)T````````(`````````````````````0`````````(
M`````````+,````.`````P````````#@K0```````."=````````"```````
M``````````````@`````````"`````````"_````#P````,`````````Z*T`
M``````#HG0````````@````````````````````(``````````@`````````
MRP````8````#`````````/"M````````\)T````````0`@````````8`````
M````"``````````0`````````-0````!`````P``````````L`````````"@
M````````4`````````````````````@```````````````````#:`````0``
M``,`````````4+````````!0H````````$`"```````````````````(````
M``````@`````````WP````@````#`````````)"R````````D*(````````H
M````````````````````"````````````````````.0````!````,```````
M`````````````)"B````````'@````````````````````$``````````0``
M``````#M`````P``<`````````````````````"NH@```````%,`````````
M```````````!`````````````````````0````,`````````````````````
K`````:,```````#_`````````````````````0``````````````````````
